﻿vatModule.controller('VatRevenueConfigController', ['$scope', '$log', '$translate', '$timeout', 'SweetAlert', '$q',
    '$interval', 'dxDataGridService', '$http', 'apiConfig',
    function ($scope, $log, $translate, $timeout, SweetAlert, $q, $interval, dxDataGridService, $http, apiConfig) {
        'use strict';

        //表格配置
        $scope.revenueGridOptions = $.extend(true, {}, dxDataGridService.BASIC_GRID_OPTIONS, {
            columns: [
                {dataField: 'idStr', caption: '', visible: false},
                {
                    dataField: 'name',
                    caption: $translate.instant('RevenueColName'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    minWidth: '300px'
                },
                {
                    dataField: 'orgId',
                    caption: $translate.instant('RevenueColOrg'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    minWidth: '300px',
                    calculateCellValue: function (data) {
                        return _.find($scope.selectOrgList, function (o) {
                            return o.id === data.orgId;
                        }).name;
                    }
                },
                //todo 组装accountName
                {
                    dataField: 'accountTypeStr',
                    caption: $translate.instant('RevenueColAccountName'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '100px'
                },
                {
                    dataField: 'taxRate',
                    caption: $translate.instant('RevenueColTaxRate'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '50px',
                    calculateCellValue: function (data) {
                        return (data.taxRate * 100) + '%';
                    }
                },
                {
                    dataField: 'taxBaseStr',
                    caption: $translate.instant('RevenueColTaxBase'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '120px'
                },
                {
                    dataField: 'revenueTypeStr',
                    caption: $translate.instant('RevenueColType'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    minWidth: '250px'
                },
                {
                    dataField: 'taxTypeStr',
                    caption: $translate.instant('RevenueColTaxType'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '120px'
                },
                {
                    dataField: 'statusStr',
                    caption: $translate.instant('RevenueColStatus'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '50px'
                },
                {
                    dataField: 'startDate',
                    caption: $translate.instant('RevenueColEnable'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '120px'
                },
                {
                    dataField: 'endDate',
                    caption: $translate.instant('RevenueColDisable'),
                    fixed: true,
                    allowHeaderFiltering: true,
                    width: '120px'
                },
                {
                    dataField: '',
                    caption: $translate.instant('RevenueColEdit'),
                    fixed: true,
                    width: '80px',
                    alignment: 'center',
                    cellTemplate: function (container, options) {
                        try {
                            $('<i class="fa fa-pencil-square-o" style="cursor: pointer"></i>&nbsp;&nbsp;')
                                .on('click', function () {
                                    $scope.editConfig(options.data);
                                }).appendTo(container);
                            $('<i class="fa fa-trash" style="cursor: pointer;margin-left: 5px;"></i>')
                                .on('click', function () {
                                    $scope.delConfig([options.data.idStr]);
                                }).appendTo(container);
                        } catch (e) {
                            $log.error(e);
                        }
                    }
                },
            ],
            bindingOptions: {
                dataSource: 'pageConfDataSource',
            },
            selection: {
                mode: 'multiple',
                showCheckBoxesMode: 'always',
                allowSelectAll: true
            },
            onSelectionChanged: function (data) {
                $scope.selectedItems = data.selectedRowsData;
                $scope.selectedRecourdCount = data.selectedRowsData.length;
            },
        });

        //刷新页面
        $scope.refreshConfigGrid = function () {
            $http.post('/revenueConf/queryPage', {pageInfo: $scope.pagingOptions}, apiConfig.createVat())
                .success(function (res) {
                    if (res && res.list) {
                        $scope.pageConfDataSource = res.list;
                        $scope.pagingOptions.totalItems = res.pageInfo.totalCount;
                    } else {
                        SweetAlert.error($translate.instant('SystemError'));
                    }
                })
        };

        //添加配置
        $scope.addConfig = function () {
            $scope.isEdit = false;
            $scope.isOrgReadOnly = false;
            $($scope.revenueConfAddDiv).modal('show');
        };

        //删除配置
        $scope.delConfig = function (idList) {
            $http.post('/revenueConf/del', idList, apiConfig.createVat())
                .success(function (res) {
                    if (res && 0 === res.code) {
                        SweetAlert.success($translate.instant('RevenueDelSuccess'));
                        $scope.refreshConfigGrid();
                    } else {
                        SweetAlert.error($translate.instant('SystemError'));
                    }
                })
        };

        $scope.batchDelConfig = function () {
            if (!!$scope.selectedRecourdCount) {
                $scope.delConfig(_.map($scope.selectedItems, function (item) {
                    return item.idStr;
                }));
            } else {
                SweetAlert.warning($translate.instant('PleaseSelectAtLeastOneItem'));
            }
        };

        //添加配置
        $scope.saveConfig = function () {
            parseTaxBase();

            if ($scope.formParam.name === undefined || $scope.formParam.name === "" ||
                $scope.formParam.orgList === undefined ||
                $scope.formParam.revenueType === undefined ||
                $scope.formParam.taxRate === undefined ||
                $scope.formParam.taxBase === undefined ||
                $scope.formParam.taxType === undefined ||
                $scope.formParam.status === undefined ||
                $scope.formParam.startDate === undefined ||
                $scope.formParam.endDate === undefined) {
                SweetAlert.warning("InputAllMandatoryInfo");
                return;
            }

            if ($scope.isEdit) {
                $http.post('/revenueConf/update', $scope.formParam, apiConfig.createVat())
                    .success(function (res) {
                        if (res && 0 === res.code) {
                            SweetAlert.success($translate.instant('RevenueAddSuccess'));
                            $scope.refreshConfigGrid();
                            $($scope.revenueConfAddDiv).modal('hide');
                            $scope.cancelModal();
                        } else {
                            SweetAlert.error($translate.instant('SystemError'));
                        }
                    })
            } else {
                $http.post('/revenueConf/add', $scope.formParam, apiConfig.createVat())
                    .success(function (res) {
                        if (res && 0 === res.code) {
                            SweetAlert.success($translate.instant('RevenueAddSuccess'));
                            $scope.refreshConfigGrid();
                            $($scope.revenueConfAddDiv).modal('hide');
                            $scope.cancelModal();
                        } else {
                            SweetAlert.error($translate.instant('SystemError'));
                        }
                    })
            }
        };

        //关闭配置框
        $scope.cancelModal = function () {
            $scope.formParam = {
                startDate: null,
                endDate: null,
            };
            $('#configForm')[0].reset();
            $scope.isShowBaseCrCode = false;
            $scope.isAccount = false;
        };

        //编辑
        $scope.editConfig = function (data) {
            $scope.isEdit = true;
            $scope.isOrgReadOnly = true;
            $scope.formParam = data;
            $scope.formParam.orgList = [data.orgId];
            if (4 === $scope.formParam.taxBase) {
                $scope.formParam.baseCrCode = $scope.formParam.baseDrCode;
            }
            $($scope.revenueConfAddDiv).modal('show');
        };

        //获取机构列表
        function getMyOrgList() {
            $http.get('/org/getMyOrgList', apiConfig.createVat())
                .success(function (res) {
                    if (res && 0 === res.code) {
                        $scope.selectOrgList = res.data;
                        $scope.refreshConfigGrid();
                    } else {
                        SweetAlert.error($translate.instant('RevenueGetOrgError'));
                    }
                })
        }

        function parseTaxBase() {
            if ($scope.formParam.taxBase) {
                if (4 === $scope.formParam.taxBase) {
                    $scope.formParam.baseDrCode = $scope.formParam.baseCrCode;
                    $scope.formParam.baseCrCode = '';
                } else if (4 !== $scope.formParam.taxBase && 5 !== $scope.formParam.taxBase) {
                    $scope.formParam.baseCrCode = '';
                    $scope.formParam.baseDrCode = '';
                }
            }
        }


        (function initialize() {

            //分页的设置
            $scope.pagingOptions = {
                pageIndex: 1,  //当前页码
                totalItems: 0,  //总数据
                pageSize: 20,  //每页多少条数据
            };

            $scope.formParam = {};

            $scope.isAccount = false;
            $scope.isShowBaseCrCode = false;
            $scope.isOrgReadOnly = false;

            //机构下拉设置
            $scope.selectOrgOptions = {
                displayExpr: 'name',
                valueExpr: 'id',
                width: '95%',
                bindingOptions: {
                    value: 'formParam.orgList',
                    dataSource: 'selectOrgList',
                    readOnly: 'isOrgReadOnly'
                },
                height: '30px',
                placeholder: '',
                showClearButton: true,
                searchEnabled: true,
                noDataText: $translate.instant('RevenueNoOrgData'),
                showSelectionControls: true
            };

            //税率下拉框
            $scope.selectTaxRateOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.taxRate'
                },
                dataSource: [
                    {'key': '0%', 'val': 0},
                    {'key': '1.5%', 'val': 0.015},
                    {'key': '3%', 'val': 0.03},
                    {'key': '5%', 'val': 0.05},
                    {'key': '6%', 'val': 0.06},
                    {'key': '10%', 'val': 0.1},
                    {'key': '16%', 'val': 0.16},
                ]
            };

            //计税基础下拉
            $scope.selectTaxBaseOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.taxBase'
                },
                dataSource: [
                    {'key': '账载收入', 'val': 1},
                    {'key': '开票收入', 'val': 2},
                    {'key': '手工录入', 'val': 3},
                    {'key': '借方发生额', 'val': 4},
                    {'key': '贷方发生额', 'val': 5},
                ],
                onSelectionChanged: function (e) {
                    if (!e.selectedItem) {
                        return;
                    }
                    if (4 === e.selectedItem.val || 5 === e.selectedItem.val) {
                        $scope.isShowBaseCrCode = true;
                    } else {
                        $scope.isShowBaseCrCode = false;
                    }
                }
            };

            //账载收入下拉
            $scope.selectAccountTypeOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.accountType'
                },
                dataSource: [
                    {'key': '0值', 'val': 0},
                    {'key': '科目', 'val': 1},
                    {'key': '手工录入', 'val': 2},
                ],
                onSelectionChanged: function (e) {
                    if (!e.selectedItem) {
                        return;
                    }
                    if (1 === e.selectedItem.val) {
                        $scope.isAccount = true;
                    } else {
                        $scope.isAccount = false;
                    }
                }
            };

            $scope.selectRevenueTypeOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.revenueType'
                },
                dataSource: [
                    {'key': '货物及加工修理修配劳务', 'val': 0},
                    {'key': '服务、不动产和无形资产', 'val': 1},
                ]
            };

            $scope.selectTaxTypeOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.taxType'
                },
                dataSource: [
                    {'key': '一般计税', 'val': 0},
                    {'key': '简易计税', 'val': 1},
                    {'key': '免抵退税', 'val': 2},
                    {'key': '免税', 'val': 3},
                ]
            };

            $scope.selectStatusOptions = {
                displayExpr: 'key',
                valueExpr: 'val',
                bindingOptions: {
                    value: 'formParam.status'
                },
                dataSource: [
                    {'key': '启用', 'val': 0},
                    {'key': '停用', 'val': 1},
                ]
            };

            $scope.dateBoxStart = {
                width: '100%',
                acceptCustomValue: false,
                openOnFieldClick: true,
                displayFormat: 'yyyy-MM',
                maxZoomLevel: "year",
                dateSerializationFormat: 'yyyy-MM',
                bindingOptions: {
                    value: 'formParam.startDate'
                }
            };

            $scope.dateBoxEnd = {
                width: '100%',
                acceptCustomValue: false,
                openOnFieldClick: true,
                displayFormat: 'yyyy-MM',
                maxZoomLevel: "year",
                dateSerializationFormat: 'yyyy-MM',
                bindingOptions: {
                    value: 'formParam.endDate'
                }
            };


            $scope.revenueConfAddDiv = ".vat-revenue-config #revenueConfAddDiv";

            function init() {
                getMyOrgList();

            }

            init()

        })();
    }
]);




